@@ -45,6 +45,8 @@ var config = {
     targetReleasePackagePath:function(){return path.join(this.targetWebRootPath(),  "/release/");},
     //测试website 服务器目录
     targetDevelopServerPath:function(){return path.join(this.targetWebRootPath(),  "/dev-server/");},
+    //测试website 服务器目录
+    targetBuildDistPath:function(){return path.join(this.targetWebRootPath(),  "/dist/");},
 
     targetWebResourceCommonPath:function(){return path.join(this.targetWebResourceRootPath(), "common/");},
     //代码生成目标目录---每个模块目录
@@ -173,7 +175,7 @@ function generateFrameworkDirectories(){
     console.log("serverRootPath:" + config.targetRootPath + "webRootPath" + config.targetWebRootPath());
 
     xtools.mkdirX(config.targetWebRootPath());
-    //xtools.mkdirX(config.targetWebResourceFrameworkPath());
+    xtools.mkdirX(config.targetBuildDistPath());
     xtools.mkdirX(path.join(config.targetWebResourceRootPath(), '/common/'));
     xtools.mkdirX(config.targetReleasePackagePath());
 }
@@ -233,6 +235,11 @@ function copyReleaseFrameworkFiles(){
     var frameworkReleasePath = config.workCopyFilesTemplatePath() + "/release/";
     xtools.copyDirEx(frameworkReleasePath,config.targetReleasePackagePath());
 
+    var workTestIndexFile = config.workCopyFilesTemplatePath() + "/release/index.html";
+    var targetTestIndexFile = config.targetBuildDistPath() + "/index.html"
+
+    fs.writeFileSync(targetTestIndexFile,fs.readFileSync(workTestIndexFile, 'utf-8'),'utf-8');
+
     var frameworkThemePath = config.workCopyFilesTemplatePath() + "/dev-server/";
     xtools.copyDirEx(frameworkThemePath,config.targetDevelopServerPath());
 }
